@@ -1,8 +1,6 @@
 import copy
 import sys
 
-import six
-
 
 class Field(object):
     def __init__(self, label=None, read_only=False):
@@ -25,17 +23,12 @@ class Field(object):
         return value
 
     def __str__(self):
-        if sys.version_info >= (3, ):
-            return self.label
-        return self.__unicode__().encode(sys.getdefaultencoding(), 'replace')
-
-    def __unicode__(self):
         return self.label
 
     def __repr__(self):
         return "<{cls} '{label}'>".format(
-            cls=six.text_type(self.__class__.__name__),
-            label=six.text_type(self) if self._label else '(No Label)',
+            cls=str(self.__class__.__name__),
+            label=str(self) if self._label else '(No Label)',
         )
 
     def __eq__(self, other):
